==> kdelibs-3.0.1.tar.bz2: kdelibs-3.0.1/khtml/ecma/kjs_navigator.h <==
// -*- c-basic-offset: 2 -*-
/*
 *  This file is part of the KDE libraries
 *  Copyright (C) 2000 Harri Porten (porten@kde.org)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef _KJS_NAVIGATOR_H_
#define _KJS_NAVIGATOR_H_

#include <kjs/object.h>

class KHTMLPart;

namespace KJS {

  class Navigator : public ObjectImp {
  public:
    Navigator(ExecState *exec, KHTMLPart *p);
    virtual Value get(ExecState *exec, const UString &propertyName) const;
    Value getValueProperty(ExecState *exec, int token) const;
    virtual const ClassInfo* classInfo() const { return &info; }
    static const ClassInfo info;
    enum { AppCodeName, AppName, AppVersion, Language, UserAgent, Platform,
           _Plugins, _MimeTypes, Product, Vendor, CookieEnabled, JavaEnabled };
    KHTMLPart *part() const { return m_part; }
  private:
    KHTMLPart *m_part;
  };
}; // namespace

#endif

==> kdelibs-3.1.tar.bz2: kdelibs-3.1/khtml/ecma/kjs_navigator.h <==
// -*- c-basic-offset: 2 -*-
/*
 *  This file is part of the KDE libraries
 *  Copyright (C) 2000 Harri Porten (porten@kde.org)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef _KJS_NAVIGATOR_H_
#define _KJS_NAVIGATOR_H_

#include <kjs/object.h>

class KHTMLPart;

namespace KJS {

  class Navigator : public ObjectImp {
  public:
    Navigator(ExecState *exec, KHTMLPart *p);
    virtual Value get(ExecState *exec, const UString &propertyName) const;
    Value getValueProperty(ExecState *exec, int token) const;
    virtual const ClassInfo* classInfo() const { return &info; }
    static const ClassInfo info;
    enum { AppCodeName, AppName, AppVersion, Language, UserAgent, UserLanguage, Platform,
           _Plugins, _MimeTypes, Product, Vendor, CookieEnabled, JavaEnabled };
    KHTMLPart *part() const { return m_part; }
  private:
    KHTMLPart *m_part;
  };
}; // namespace

#endif
